# GAMs
GAM model types from ``pymgcv.gam``.


::: pymgcv.gam.GAM
    options:
        heading_level: 2
        inherited_members: __init__

::: pymgcv.gam.BAM
    options:
        heading_level: 2
        inherited_members: __init__

::: pymgcv.gam.AbstractGAM
    options:
        heading_level: 2
        merge_init_into_class: false
        filters:
          - "!^_"
          - "!fit"
          - "!predict"
          - "!partial_effects"

::: pymgcv.gam.FitState
    options:
        heading_level: 2

::: pymgcv.gam.FitAndSE
    options:
        heading_level: 2
